@@ -4,7 +4,7 @@
 modname = 'vcsfile'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 1, 0)
+numversion = (1, 2, 0)
 version = '.'.join(str(num) for num in numversion)
 
 copyright = '''Copyright (c) 2007-2010 LOGILAB S.A. (Paris, FRANCE).
@@ -53,12 +53,10 @@ for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18
 # Note: here, you'll need to add subdirectories if you want
 # them to be included in the debian package
 
-cube_eid = None # XXX
 # used packages
 __depends_cubes__ = {}
-__depends__ = {'cubicweb': '>= 3.6.0',
+__depends__ = {'cubicweb': '>= 3.6.1',
                'logilab-mtconverter': '>= 0.7.0',
-               'pysqlite': None,
                }
 __use__ = tuple(__depends_cubes__)
 classifiers = [
