@@ -10,7 +10,7 @@ __docformat__ = "restructuredtext en"
 from logilab.common.decorators import cached, clear_cache
 from logilab.common.compat import any
 
-from cubicweb import QueryError, Binary
+from cubicweb import QueryError, Binary, Unauthorized
 from cubicweb.interfaces import IPrevNext, IDownloadable
 from cubicweb.entities import AnyEntity, fetch_config
 
@@ -165,8 +165,12 @@ class Revision(AnyEntity):
             return self._cw._('revision #%s') % self.revision
 
     def dc_long_title(self):
-        return self._cw._('%(rev)s of repository %(repo)s') % {
-            'rev': self.dc_title(), 'repo': self.repository.dc_title()}
+        try:
+            return self._cw._('%(rev)s of repository %(repo)s') % {
+                'rev': self.dc_title(), 'repo': self.repository.dc_title()}
+        except Unauthorized:
+            return self._cw._('%(rev)s of a private repository') % {
+                'rev': self.dc_title()}
 
     def sortvalue(self, rtype=None):
         if rtype is None:
@@ -190,7 +194,10 @@ class Revision(AnyEntity):
             return rset.get_entity(0, 0)
 
     def parent(self): # for breadcrumbs
-        return self.repository
+        try:
+            return self.repository
+        except Unauthorized:
+            return None
 
     def pre_web_edit(self):
         """callback called by the web editcontroller when an entity will be
@@ -222,12 +229,19 @@ class VersionedFile(AnyEntity):
         return self.path
 
     def dc_long_title(self):
-        return self._cw._('%(path)s (from repository %(repotype)s:%(repo)s)') % {
-            'path': self.dc_title(), 'repo': self.repository.path,
-            'repotype': self.repository.type}
+        try:
+            return self._cw._('%(path)s (from repository %(repotype)s:%(repo)s)') % {
+                'path': self.dc_title(), 'repo': self.repository.path,
+                'repotype': self.repository.type}
+        except Unauthorized:
+            return self._cw._('%(path)s (from private repository)') % {
+                'path': self.dc_title(),}
 
     def parent(self): # for breadcrumbs
-        return self.repository
+        try:
+            return self.repository
+        except Unauthorized:
+            return None
 
     def clear_all_caches(self):
         super(VersionedFile, self).clear_all_caches()
