@@ -56,7 +56,7 @@ class VCSRepository(object):
     def canonicalize(self, path):
         return path
 
-    def import_content(self, repoentity):
+    def import_content(self, repoentity, commitevery=10):
         """import content from the repository"""
         raise NotImplementedError()
 
