@@ -105,6 +105,8 @@ class HGRepository(repo.VCSRepository):
                                   {'r': self.eid})
         revdata['parents'] = [r[0] for r in parents]
         reveid = bridge.import_revision(session, self.eid, **revdata)
+        if not repoentity._cw.vreg.config['import-revision-content']:
+            return
         changes = repo.status(ctx.parents()[0].node(), ctx.node())[:3]
         modified, added, removed = changes
         path_filter = repoentity.subpath
@@ -144,6 +146,7 @@ class HGRepository(repo.VCSRepository):
                 continue
             bridge.import_deleted_version_content(session, self.eid, reveid,
                                                   upath, date)
+        # The line below is duplicated at the middle of the function
         bridge.set_at_revision(session, reveid)
 
     def hgrepo(self):
