@@ -61,7 +61,9 @@ class SVNRepository(repo.VCSRepository):
             self.info('importing content of %s for revision %s', self, rev)
             self.imported_revision = rev # for hooks
             # the base of the comparison
-            editor = SVNImporter(repoentity, fsrep, base_root, rev)
+            editor = SVNImporter(repoentity, fsrep, base_root, rev,
+                                 import_revision_content = repoentity._cw
+                                 .vreg.config['import-revision-content'])
             try:
                 editor.import_revision()
             except:
@@ -173,10 +175,12 @@ class SVNTransaction(object):
 
 
 class SVNImporter(delta.Editor):
-    def __init__(self, repoentity, fsrep, base_root, rev):
+    def __init__(self, repoentity, fsrep, base_root, rev,
+                 import_revision_content=True):
         self.repoeid = repoentity.eid
         self.encoding = repoentity.encoding
         self.session = repoentity._cw
+        self.import_revision_content = import_revision_content
         path_filter = repoentity.subpath
         if isinstance(path_filter, unicode):
             # if we don't encode we may get unicode error when comparing files'
@@ -273,7 +277,7 @@ class SVNImporter(delta.Editor):
         pass
 
     def add_file(self, path, *args):
-        if self.match_path(path):
+        if self .import_revision_content and self.match_path(path):
             upath = unicode(path, self.encoding, 'replace')
             bridge.import_version_content(
                 self.session, self.repoeid, self.reveid, upath, self.date)
