@@ -44,9 +44,9 @@ class Revision(EntityType):
     revision = Int(required=True, indexed=True,
                    description=_('revision number.'))
 
-    description = String(fulltextindexed=True, description=_('comment for this revision.'))
+    description = String(description=_('comment for this revision.'))
 
-    author = String(indexed=True, fulltextindexed=True, maxsize=200,
+    author = String(indexed=True, maxsize=200,
                     description=_("author of this revision."))
 
     changeset = String(indexed=True, maxsize=100,
@@ -59,7 +59,6 @@ class Revision(EntityType):
 
     from_repository = SubjectRelation('Repository', cardinality='1*', composite='object')
     parent_revision = SubjectRelation('Revision')
-    ancestor_revision = SubjectRelation('Revision')
 
 
 class VersionedFile(EntityType):
@@ -70,10 +69,9 @@ class VersionedFile(EntityType):
         'update': (),
         'delete': (),
         }
-    directory = String(required=True, fulltextindexed=True, indexed=True,
+    directory = String(required=True, indexed=True,
                        description=_('directory of the file in the repository.'))
-    name = String(required=True, fulltextindexed=True,
-                  description=_('name of the file in the repository.'))
+    name = String(required=True,                   description=_('name of the file in the repository.'))
     from_repository = SubjectRelation('Repository', cardinality='1*', composite='object')
 
 
@@ -93,7 +91,7 @@ class VersionContent(DeletedVersionContent):
     """actual content of a versioned file, for a given revision"""
     # not required to avoid yams validation error since it's not actually stored
     # in the database
-    data = Bytes(fulltextindexed=True, description=_("file's data"))
+    data = Bytes(description=_("file's data"))
     data_format = String(required=True, meta=True, maxsize=50,
                          description=_('MIME type of the file.'))
     data_encoding = String(meta=True, maxsize=20,
