@@ -23,6 +23,14 @@ should be commited (default to 1, e.g. on each revision).',
           'inputlevel': 2,
           'group': 'vcsfile',
           }),
+        ('import-revision-content',
+         {'type' : 'yn',
+          'default': True,
+          'help': 'Import content of file touched by a revision. This may \
+cause performance issue when scaling.',
+          'inputlevel': 2,
+          'group': 'vcsfile',
+          }),
         )
 
 
